==> cramr_ui_lib-1.0.12.tar.gz: lib/routes/verb_selectionmode_selection_route.dart <==
import 'package:cramr_ui_lib/ads/safe_banner_ad_widget.dart';
import 'package:cramr_ui_lib/routes/conjugation_selection_route.dart';
import 'package:cramr_ui_lib/routes/multi_conjugation_verb_selection_route.dart';
import 'package:cramr_ui_lib/widgets/delayed_widget_builder.dart';
import 'package:flutter/material.dart';
import '../settings/settings_controller.dart';
import '../settings/settings_view.dart';
import '../theme/custom_theme.dart';
import '../util/text_size_limiter.dart';

class VerbSelectionmodeSelectionRoute extends StatefulWidget {
  static const routeName = '/verbSelectionmodeSelectionRoute';

  final SettingsController _settingsController;
  final SafeBannerAdWidget safeBannerAdWidget;

  const VerbSelectionmodeSelectionRoute(this._settingsController,
      {Key? key, required this.safeBannerAdWidget})
      : super(key: key);

  @override
  State<VerbSelectionmodeSelectionRoute> createState() {
    return VerbSelectionmodeSelectionRouteState();
  }
}

class VerbSelectionmodeSelectionRouteState
    extends State<VerbSelectionmodeSelectionRoute> {
  @override
  void initState() {
    super.initState();
    // final adsController = context.read<AdsController?>();
    // adsController?.preloadAd(VerbOrModeSelectionBannerAdWidget.adUnitId);
  }

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
        animation: widget._settingsController,
        builder: (BuildContext context, Widget? child) {
          return MaterialApp(
            debugShowCheckedModeBanner: false,
            themeMode: widget._settingsController.themeMode,
            theme: CustomTheme.lightTheme,
            darkTheme: ThemeData.dark(),
            home: SafeArea(
                child: Scaffold(
                    appBar: AppBar(
                      actions: [_settingsIcon(context)],
                    ),
                    body: Column(
                      children: [
                        Expanded(
                          child: ListView(
                            key: const Key('verbSelectionModeSelection'),
                            children: [
                              _buildCard(
                                  context,
                                  const Key('byVerbMode'),
                                  'verb',
                                  'WERKWOORD',
                                  '(aimer, avoir, être, venir, ...)'),
                              _buildCard(
                                  context,
                                  const Key('byConjugationMode'),
                                  'conjugation',
                                  'VERVOEGING',
                                  '(indicatif présent, indicatif imparfait, ...)'),
                            ],
                          ),
                        ),
                        Container(
                          height: 100.0,
                          alignment: Alignment.center,
                          child: widget.safeBannerAdWidget,
                        )
                      ],
                    ))),
          );
        });
  }

  void _launchNextRoute(BuildContext context, String mode) {
    if ('verb' == mode) {
      Navigator.pushNamed(
          //Navigator.restorablePopAndPushNamed(
          context,
          MultiConjugationVerbSelectionRoute.routeName);
    } else if ('conjugation' == mode) {
      Navigator.pushNamed(
          //Navigator.restorablePopAndPushNamed(
          context,
          ConjugationSelectionRoute.routeName);
    }
  }

  IconButton _settingsIcon(BuildContext context) {
    return IconButton(
        key: const Key('settingsButton'),
        icon: const Icon(Icons.settings),
        onPressed: () {
          Navigator.pushNamed(context, SettingsView.routeName);
        });
  }

  Widget _buildCard(BuildContext context, Key buttonKey, String mode,
      String modeName, String modeExample) {
    return Center(
      child: SizedBox(
        width: MediaQuery.of(context).size.width * .95,
        child: Card(
          margin: const EdgeInsets.fromLTRB(30, 15, 30, 15),
          elevation: 20,
          child: Column(
            children: [
              Padding(
                key: UniqueKey(),
                padding: const EdgeInsets.fromLTRB(10, 10, 10, 10),
                child: Text(
                  'Oefen per',
                  key: UniqueKey(),
                  style: Theme.of(context).textTheme.headline3,
                  textScaleFactor: TextSizeLimiter.textScaleFactor(context),
                  textAlign: TextAlign.center,
                ),
              ),
              Padding(
                key: UniqueKey(),
                padding: const EdgeInsets.fromLTRB(10, 10, 10, 10),
                child: Text(
                  modeName,
                  key: UniqueKey(),
                  style: Theme.of(context).textTheme.headline4,
                  textScaleFactor: TextSizeLimiter.textScaleFactor(context),
                  textAlign: TextAlign.center,
                ),
              ),
              Padding(
                padding: const EdgeInsets.fromLTRB(10, 10, 10, 10),
                child: Text(
                  modeExample,
                  key: UniqueKey(),
                  style: Theme.of(context).textTheme.headline5,
                  textScaleFactor: TextSizeLimiter.textScaleFactor(context),
                  textAlign: TextAlign.center,
                ),
              ),
              Padding(
                padding: const EdgeInsets.fromLTRB(10, 10, 10, 10),
                child: DelayedWidgetBuilder(
                  delay: const Duration(seconds: 1),
                  child: InkWell(
                    key: buttonKey,
                    onTap: () {
                      _launchNextRoute(context, mode);
                    },
                    child: CircleAvatar(
                        key: UniqueKey(), child: const Icon(Icons.play_arrow)),
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> cramr_ui_lib-1.0.13.tar.gz: lib/routes/verb_selectionmode_selection_route.dart <==
import 'package:cramr_ui_lib/ads/safe_banner_ad_widget.dart';
import 'package:cramr_ui_lib/routes/conjugation_selection_route.dart';
import 'package:cramr_ui_lib/routes/multi_conjugation_verb_selection_route.dart';
import 'package:cramr_ui_lib/widgets/delayed_widget_builder.dart';
import 'package:flutter/material.dart';
import '../settings/settings_controller.dart';
import '../settings/settings_view.dart';
import '../theme/custom_theme.dart';
import '../util/text_size_limiter.dart';

class VerbSelectionmodeSelectionRoute extends StatefulWidget {
  static const routeName = '/verbSelectionmodeSelectionRoute';

  final SettingsController _settingsController;
  final SafeBannerAdWidget safeBannerAdWidget;

  const VerbSelectionmodeSelectionRoute(this._settingsController,
      {Key? key, required this.safeBannerAdWidget})
      : super(key: key);

  @override
  State<VerbSelectionmodeSelectionRoute> createState() {
    return VerbSelectionmodeSelectionRouteState();
  }
}

class VerbSelectionmodeSelectionRouteState
    extends State<VerbSelectionmodeSelectionRoute> {
  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
        animation: widget._settingsController,
        builder: (BuildContext context, Widget? child) {
          return MaterialApp(
            debugShowCheckedModeBanner: false,
            themeMode: widget._settingsController.themeMode,
            theme: CustomTheme.lightTheme,
            darkTheme: ThemeData.dark(),
            home: SafeArea(
                child: Scaffold(
                    appBar: AppBar(
                      leading: IconButton(
                          key: const Key('BackKey'),
                          onPressed: () {
                            Navigator.pop(context);
                          },
                          icon: const Icon(Icons.arrow_back)),
                      actions: [_settingsIcon(context)],
                    ),
                    body: Column(
                      children: [
                        Expanded(
                          child: ListView(
                            key: const Key('verbSelectionModeSelection'),
                            children: [
                              _buildCard(
                                  context,
                                  const Key('byVerbMode'),
                                  'verb',
                                  'WERKWOORD',
                                  '(aimer, avoir, être, venir, ...)'),
                              _buildCard(
                                  context,
                                  const Key('byConjugationMode'),
                                  'conjugation',
                                  'VERVOEGING',
                                  '(indicatif présent, indicatif imparfait, ...)'),
                            ],
                          ),
                        ),
                        Container(
                          height: 100.0,
                          alignment: Alignment.center,
                          child: widget.safeBannerAdWidget,
                        )
                      ],
                    ))),
          );
        });
  }

  void _launchNextRoute(BuildContext context, String mode) {
    if ('verb' == mode) {
      Navigator.pushNamed(
          context, MultiConjugationVerbSelectionRoute.routeName);
    } else if ('conjugation' == mode) {
      Navigator.pushNamed(context, ConjugationSelectionRoute.routeName);
    }
  }

  IconButton _settingsIcon(BuildContext context) {
    return IconButton(
        key: const Key('settingsButton'),
        icon: const Icon(Icons.settings),
        onPressed: () {
          Navigator.pushNamed(context, SettingsView.routeName);
        });
  }

  Widget _buildCard(BuildContext context, Key buttonKey, String mode,
      String modeName, String modeExample) {
    return Center(
      child: SizedBox(
        width: MediaQuery.of(context).size.width * .95,
        child: Card(
          margin: const EdgeInsets.fromLTRB(30, 15, 30, 15),
          elevation: 20,
          child: Column(
            children: [
              Padding(
                key: UniqueKey(),
                padding: const EdgeInsets.fromLTRB(10, 10, 10, 10),
                child: Text(
                  'Oefen per',
                  key: UniqueKey(),
                  style: Theme.of(context).textTheme.headline3,
                  textScaleFactor: TextSizeLimiter.textScaleFactor(context),
                  textAlign: TextAlign.center,
                ),
              ),
              Padding(
                key: UniqueKey(),
                padding: const EdgeInsets.fromLTRB(10, 10, 10, 10),
                child: Text(
                  modeName,
                  key: UniqueKey(),
                  style: Theme.of(context).textTheme.headline4,
                  textScaleFactor: TextSizeLimiter.textScaleFactor(context),
                  textAlign: TextAlign.center,
                ),
              ),
              Padding(
                padding: const EdgeInsets.fromLTRB(10, 10, 10, 10),
                child: Text(
                  modeExample,
                  key: UniqueKey(),
                  style: Theme.of(context).textTheme.headline5,
                  textScaleFactor: TextSizeLimiter.textScaleFactor(context),
                  textAlign: TextAlign.center,
                ),
              ),
              Padding(
                padding: const EdgeInsets.fromLTRB(10, 10, 10, 10),
                child: DelayedWidgetBuilder(
                  delay: const Duration(seconds: 1),
                  child: InkWell(
                    key: buttonKey,
                    onTap: () {
                      _launchNextRoute(context, mode);
                    },
                    child: CircleAvatar(
                        key: UniqueKey(), child: const Icon(Icons.play_arrow)),
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
